";
s += __tr2qs_ctx("Transfer Log","dcc");
@@ -1477,14 +1477,14 @@ void KviDccFileTransfer::connectionInProgress()
// if(TRIGGER_EVENT_5PARAM_RETVALUE(KviEvent_OnDCCSendConnected,this,m_pDescriptor->szPort.ptr(),m_pDescriptor->szFileName.ptr(),m_pDescriptor->szNick.ptr(),m_pDescriptor->szUser.ptr(),m_pDescriptor->szHost.ptr()));
// }
//
- m_szStatusString = __tr2qs_ctx("Contacting host %1 on port %2","dcc").tqarg(m_pDescriptor->szIp).tqarg(m_pDescriptor->szPort);
+ m_szStatusString = __tr2qs_ctx("Contacting host %1 on port %2","dcc").arg(m_pDescriptor->szIp).arg(m_pDescriptor->szPort);
outputAndLog(m_szStatusString);
displayUpdate();
return;
}
// PASSIVE CONNECTION
- m_szStatusString = __tr2qs_ctx("Listening on interface %1 port %2","dcc").tqarg(m_pMarshal->localIp()).tqarg(m_pMarshal->localPort());
+ m_szStatusString = __tr2qs_ctx("Listening on interface %1 port %2","dcc").arg(m_pMarshal->localIp()).arg(m_pMarshal->localPort());
outputAndLog(m_szStatusString);
if(m_pDescriptor->bSendRequest)
@@ -1507,7 +1507,7 @@ void KviDccFileTransfer::connectionInProgress()
if(!tmp.isEmpty())
{
ip = tmp;
- outputAndLog(__tr2qs_ctx("The local IP address is private, determining from IRC server: %1","dcc").tqarg(ip));
+ outputAndLog(__tr2qs_ctx("The local IP address is private, determining from IRC server: %1","dcc").arg(ip));
} else {
outputAndLog(__tr2qs_ctx("The local IP address is private, but unable to determine it from the IRC server","dcc"));
}
@@ -1558,9 +1558,9 @@ void KviDccFileTransfer::connectionInProgress()
ip.utf8().data(),port.ptr(),
&(m_pDescriptor->szLocalFileSize),0x01);
}
- outputAndLog(__tr2qs_ctx("Sent DCC %1 request to %2, waiting for remote client to connect...","dcc").tqarg(szReq.ptr()).tqarg(m_pDescriptor->szNick));
+ outputAndLog(__tr2qs_ctx("Sent DCC %1 request to %2, waiting for remote client to connect...","dcc").arg(szReq.ptr()).arg(m_pDescriptor->szNick));
} else {
- outputAndLog(__tr2qs_ctx("DCC %1 request not sent, awaiting manual connection","dcc").tqarg(m_szDccType.ptr()));
+ outputAndLog(__tr2qs_ctx("DCC %1 request not sent, awaiting manual connection","dcc").arg(m_szDccType.ptr()));
}
KVS_TRIGGER_EVENT_1(KviEvent_OnDCCFileTransferConnectionInProgress,eventWindow(),m_pDescriptor->idString());
@@ -1579,7 +1579,7 @@ void KviDccFileTransfer::startingSSLHandshake()
void KviDccFileTransfer::sslError(const char * msg)
{
#ifdef COMPILE_SSL_SUPPORT
- outputAndLog(KVI_OUT_DCCERROR,__tr2qs_ctx("[SSL ERROR]: %1","dcc").tqarg(msg));
+ outputAndLog(KVI_OUT_DCCERROR,__tr2qs_ctx("[SSL ERROR]: %1","dcc").arg(msg));
#endif
}
@@ -1687,8 +1687,8 @@ void KviDccFileTransfer::handleMarshalError(int err)
void KviDccFileTransfer::connected()
{
- outputAndLog(__tr2qs_ctx("Connected to %1:%2","dcc").tqarg(m_pMarshal->remoteIp()).tqarg(m_pMarshal->remotePort()));
- outputAndLog(__tr2qs_ctx("Local end is %1:%2","dcc").tqarg(m_pMarshal->localIp()).tqarg(m_pMarshal->localPort()));
+ outputAndLog(__tr2qs_ctx("Connected to %1:%2","dcc").arg(m_pMarshal->remoteIp()).arg(m_pMarshal->remotePort()));
+ outputAndLog(__tr2qs_ctx("Local end is %1:%2","dcc").arg(m_pMarshal->localIp()).arg(m_pMarshal->localPort()));
m_tTransferStartTime = kvi_unixTime();
@@ -1758,7 +1758,7 @@ bool KviDccFileTransfer::resumeAccepted(const char *filename,const char *port,co
delete m_pResumeTimer;
m_pResumeTimer = 0;
- outputAndLog(__tr2qs_ctx("RESUME accepted, transfer will begin at position %1","dcc").tqarg(m_pDescriptor->szLocalFileSize));
+ outputAndLog(__tr2qs_ctx("RESUME accepted, transfer will begin at position %1","dcc").arg(m_pDescriptor->szLocalFileSize));
listenOrConnect();
@@ -1768,7 +1768,7 @@ bool KviDccFileTransfer::resumeAccepted(const char *filename,const char *port,co
if(ret != KviError_success)handleMarshalError(ret);
else {
- m_szStatusString = __tr2qs_ctx("Contacting host %1 on port %2","dcc").tqarg(m_pDescriptor->szIp).tqarg(m_pDescriptor->szPort);
+ m_szStatusString = __tr2qs_ctx("Contacting host %1 on port %2","dcc").arg(m_pDescriptor->szIp).arg(m_pDescriptor->szPort);
outputAndLog(m_szStatusString);
displayUpdate();
}
@@ -1794,11 +1794,11 @@ bool KviDccFileTransfer::doResume(const char * filename,const char * port,unsign
}
if(iLocalFileSize <= filePos)
{
- outputAndLog(KVI_OUT_DCCERROR,__tr2qs_ctx("Invalid RESUME request: Position %1 is larger than file size","dcc").tqarg(filePos));
+ outputAndLog(KVI_OUT_DCCERROR,__tr2qs_ctx("Invalid RESUME request: Position %1 is larger than file size","dcc").arg(filePos));
return false;
}
- outputAndLog(KVI_OUT_DCCERROR,__tr2qs_ctx("Accepting RESUME request, transfer will begin at position %1","dcc").tqarg(filePos));
+ outputAndLog(KVI_OUT_DCCERROR,__tr2qs_ctx("Accepting RESUME request, transfer will begin at position %1","dcc").arg(filePos));
m_pDescriptor->szFileSize.setNum(filePos);
@@ -1830,7 +1830,7 @@ KviDccFileTransferBandwidthDialog::KviDccFileTransferBandwidthDialog(TQWidget *
m_pTransfer = t;
int iVal = m_pTransfer->bandwidthLimit();
- TQString szText = __tr2qs_ctx("Configure bandwidth for DCC transfer %1","dcc").tqarg(t->id());
+ TQString szText = __tr2qs_ctx("Configure bandwidth for DCC transfer %1","dcc").arg(t->id());
setCaption(szText);
szText = t->isFileUpload() ? __tr2qs_ctx("Limit upload bandwidth to","dcc") : __tr2qs_ctx("Limit download bandwidth to","dcc");
diff --git a/src/modules/dockwidget/libkvidockwidget_qt3.cpp b/src/modules/dockwidget/libkvidockwidget_qt3.cpp
index 6978ce0..ce454b2 100644
--- a/src/modules/dockwidget/libkvidockwidget_qt3.cpp
+++ b/src/modules/dockwidget/libkvidockwidget_qt3.cpp
@@ -447,10 +447,10 @@ void KviDockWidget::fillContextPopup()
int id;
if(pConsole->connection()->userInfo()->isAway())
{
- id=m_pAwayPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CONSOLE)),__tr2qs("Back on %1").tqarg(pConsole->currentNetworkName()),this,TQT_SLOT(doAway(int)));
+ id=m_pAwayPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CONSOLE)),__tr2qs("Back on %1").arg(pConsole->currentNetworkName()),this,TQT_SLOT(doAway(int)));
bAllUnaway=0;
} else {
- id=m_pAwayPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CONSOLE)),__tr2qs("Away on %1").tqarg(pConsole->currentNetworkName()),this,TQT_SLOT(doAway(int)));
+ id=m_pAwayPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CONSOLE)),__tr2qs("Away on %1").arg(pConsole->currentNetworkName()),this,TQT_SLOT(doAway(int)));
bAllAway=0;
}
m_pAwayPopup->setItemParameter(id,pConsole->ircContextId());
diff --git a/src/modules/dockwidget/libkvidockwidget_qt4.cpp b/src/modules/dockwidget/libkvidockwidget_qt4.cpp
index d1f4eff..54033af 100644
--- a/src/modules/dockwidget/libkvidockwidget_qt4.cpp
+++ b/src/modules/dockwidget/libkvidockwidget_qt4.cpp
@@ -279,10 +279,10 @@ void KviDockWidget::fillContextPopup()
int id;
if(pConsole->connection()->userInfo()->isAway())
{
- id=m_pAwayPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CONSOLE)),__tr2qs("Back on %1").tqarg(pConsole->currentNetworkName()),this,TQT_SLOT(doAway(int)));
+ id=m_pAwayPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CONSOLE)),__tr2qs("Back on %1").arg(pConsole->currentNetworkName()),this,TQT_SLOT(doAway(int)));
bAllUnaway=0;
} else {
- id=m_pAwayPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CONSOLE)),__tr2qs("Away on %1").tqarg(pConsole->currentNetworkName()),this,TQT_SLOT(doAway(int)));
+ id=m_pAwayPopup->insertItem(*(g_pIconManager->getSmallIcon(KVI_SMALLICON_CONSOLE)),__tr2qs("Away on %1").arg(pConsole->currentNetworkName()),this,TQT_SLOT(doAway(int)));
bAllAway=0;
}
m_pAwayPopup->setItemParameter(id,pConsole->ircContextId());
diff --git a/src/modules/editor/scripteditor.cpp b/src/modules/editor/scripteditor.cpp
index 525acfd..6945cd1 100644
--- a/src/modules/editor/scripteditor.cpp
+++ b/src/modules/editor/scripteditor.cpp
@@ -369,7 +369,7 @@ void KviScriptEditorWidget::keyPressEvent(TQKeyEvent * e)
TQString szPrev=text(para-1);
if(!szPrev.isEmpty())
{
- if(szPrev.tqat(szPrev.length() - 1).tqunicode() == ' ')
+ if(szPrev.at(szPrev.length() - 1).tqunicode() == ' ')
szPrev.remove(szPrev.length() - 1,1);
TQString szCur;
const TQChar * pCur = (const TQChar *)szPrev.ucs2();
diff --git a/src/modules/filetransferwindow/filetransferwindow.cpp b/src/modules/filetransferwindow/filetransferwindow.cpp
index 3fcf59d..9274946 100644
--- a/src/modules/filetransferwindow/filetransferwindow.cpp
+++ b/src/modules/filetransferwindow/filetransferwindow.cpp
@@ -313,7 +313,7 @@ void KviFileTransferWindow::rightButtonPressed(KviTalListViewItem *it,const TQPo
if(fi.exists())
{
tmp += "";
- tmp += __tr2qs_ctx("Size: %1","filetransferwindow").tqarg(KviTQString::makeSizeReadable(fi.size()));
+ tmp += __tr2qs_ctx("Size: %1","filetransferwindow").arg(KviTQString::makeSizeReadable(fi.size()));
tmp += " ";
}
diff --git a/src/modules/http/httpfiletransfer.cpp b/src/modules/http/httpfiletransfer.cpp
index cfe9087..8ad7c8f 100644
--- a/src/modules/http/httpfiletransfer.cpp
+++ b/src/modules/http/httpfiletransfer.cpp
@@ -211,8 +211,8 @@ void KviHttpFileTransfer::displayPaint(TQPainter * p,int column,int width,int he
//iR = iW - iL;
p->fillRect(5,5,iL,10,bIsTerminated ? TQColor(140,110,110) : TQColor(200,100,100));
- txt = TQString(__tr2qs_ctx("%1 of %2 (%3 %)","http")).tqarg(KviTQString::makeSizeReadable(uRecvd))
- .tqarg(KviTQString::makeSizeReadable(uTotal)).tqarg(dPerc,0,'f',2);
+ txt = TQString(__tr2qs_ctx("%1 of %2 (%3 %)","http")).arg(KviTQString::makeSizeReadable(uRecvd))
+ .arg(KviTQString::makeSizeReadable(uTotal)).arg(dPerc,0,'f',2);
} else {
txt = KviTQString::makeSizeReadable(m_pHttpRequest->receivedSize());
}
@@ -265,17 +265,17 @@ void KviHttpFileTransfer::displayPaint(TQPainter * p,int column,int width,int he
{
KviTimeUtils::secondsToDaysHoursMinsSecs(kvi_timeSpan(m_tTransferEndTime,m_tTransferStartTime),&uD,&uH,&uM,&uS);
txt = "TOT: ";
- if(uD > 0)txt += TQString(__tr2qs_ctx("%1d %2h %3m %4s","http")).tqarg(uD).tqarg(uH).tqarg(uM).tqarg(uS);
- else if(uH > 0)txt += TQString(__tr2qs_ctx("%2h %3m %4s","http")).tqarg(uH).tqarg(uM).tqarg(uS);
- else txt += TQString(__tr2qs_ctx("%3m %4s","http")).tqarg(uM).tqarg(uS);
+ if(uD > 0)txt += TQString(__tr2qs_ctx("%1d %2h %3m %4s","http")).arg(uD).arg(uH).arg(uM).arg(uS);
+ else if(uH > 0)txt += TQString(__tr2qs_ctx("%2h %3m %4s","http")).arg(uH).arg(uM).arg(uS);
+ else txt += TQString(__tr2qs_ctx("%3m %4s","http")).arg(uM).arg(uS);
} else {
if(iEta >= 0)
{
KviTimeUtils::secondsToDaysHoursMinsSecs(iEta,&uD,&uH,&uM,&uS);
txt = "ETA: ";
- if(uD > 0)txt += TQString(__tr2qs_ctx("%1d %2h %3m %4s","http")).tqarg(uD).tqarg(uH).tqarg(uM).tqarg(uS);
- else if(uH > 0)txt += TQString(__tr2qs_ctx("%2h %3m %4s","http")).tqarg(uH).tqarg(uM).tqarg(uS);
- else txt += TQString(__tr2qs_ctx("%3m %4s","http")).tqarg(uM).tqarg(uS);
+ if(uD > 0)txt += TQString(__tr2qs_ctx("%1d %2h %3m %4s","http")).arg(uD).arg(uH).arg(uM).arg(uS);
+ else if(uH > 0)txt += TQString(__tr2qs_ctx("%2h %3m %4s","http")).arg(uH).arg(uM).arg(uS);
+ else txt += TQString(__tr2qs_ctx("%3m %4s","http")).arg(uM).arg(uS);
} else {
txt = "ETA: Unknown";
}
@@ -301,7 +301,7 @@ int KviHttpFileTransfer::displayHeight(int iLineSpacing)
TQString KviHttpFileTransfer::tipText()
{
TQString s;
- s = TQString("HTTP Transfer (ID %1) | ").tqarg(id());
+ s = TQString("HTTP Transfer (ID %1) | ").arg(id());
if(m_lRequest.count() > 0)
{
@@ -390,13 +390,13 @@ void KviHttpFileTransfer::connectionEstabilished()
void KviHttpFileTransfer::resolvingHost(const TQString &hostname)
{
- m_szStatusString = __tr2qs_ctx("Resolving host %1","http").tqarg(hostname);
+ m_szStatusString = __tr2qs_ctx("Resolving host %1","http").arg(hostname);
displayUpdate();
}
void KviHttpFileTransfer::contactingHost(const TQString &ipandport)
{
- m_szStatusString = __tr2qs_ctx("Contacting host %1","http").tqarg(ipandport);
+ m_szStatusString = __tr2qs_ctx("Contacting host %1","http").arg(ipandport);
displayUpdate();
}
@@ -404,7 +404,7 @@ void KviHttpFileTransfer::receivedResponse(const TQString &response)
{
m_lHeaders.clear();
m_lHeaders.append(response);
- m_szStatusString = __tr2qs_ctx("Transferring data (%1)","http").tqarg(response);
+ m_szStatusString = __tr2qs_ctx("Transferring data (%1)","http").arg(response);
m_tTransferStartTime = kvi_unixTime();
m_eGeneralStatus = Downloading;
displayUpdate();
diff --git a/src/modules/links/linkswindow.cpp b/src/modules/links/linkswindow.cpp
index 51ebce1..f2f51dd 100644
--- a/src/modules/links/linkswindow.cpp
+++ b/src/modules/links/linkswindow.cpp
@@ -301,7 +301,7 @@ void KviLinksWindow::endOfLinks()
while(!m_pLinkList->isEmpty())m_pLinkList->removeFirst();
m_pListView->setUpdatesEnabled(true);
- m_pListView->tqrepaint();
+ m_pListView->repaint();
}
KviTalListViewItem * KviLinksWindow::insertLink(KviLink *l)
diff --git a/src/modules/logview/logviewmdiwindow.cpp b/src/modules/logview/logviewmdiwindow.cpp
index bab0a96..55b3622 100644
--- a/src/modules/logview/logviewmdiwindow.cpp
+++ b/src/modules/logview/logviewmdiwindow.cpp
@@ -202,11 +202,11 @@ void KviLogViewMDIWindow::fillCaptionBuffers()
{
m_szPlainTextCaption = __tr2qs_ctx("Log Viewer","logview");
- m_szHtmlActiveCaption = TQString("").tqarg(TQString(KVI_OPTION_COLOR(KviOption_colorCaptionTextActive).name()).ascii());
+ m_szHtmlActiveCaption = TQString("").arg(TQString(KVI_OPTION_COLOR(KviOption_colorCaptionTextActive).name()).ascii());
m_szHtmlActiveCaption.append(m_szPlainTextCaption);
m_szHtmlActiveCaption.append("");
- m_szHtmlInactiveCaption = TQString("").tqarg(TQString(KVI_OPTION_COLOR(KviOption_colorCaptionTextInactive).name()).ascii());
+ m_szHtmlInactiveCaption = TQString("").arg(TQString(KVI_OPTION_COLOR(KviOption_colorCaptionTextInactive).name()).ascii());
m_szHtmlInactiveCaption.append(m_szPlainTextCaption);
m_szHtmlInactiveCaption.append("");
}
@@ -361,7 +361,7 @@ void KviLogViewMDIWindow::itemSelected(KviTalListViewItem * it)
else
outputNoFmt(0,*it,KviIrcView::NoRepaint | KviIrcView::NoTimestamp);
}
- m_pIrcView->tqrepaint(false);
+ m_pIrcView->repaint(false);
}
TQStringList KviLogViewMDIWindow::getFileNames()
diff --git a/src/modules/mircimport/libkvimircimport.cpp b/src/modules/mircimport/libkvimircimport.cpp
index bdd21f1..e106623 100644
--- a/src/modules/mircimport/libkvimircimport.cpp
+++ b/src/modules/mircimport/libkvimircimport.cpp
@@ -243,7 +243,7 @@ void KviRemoteMircServerImportWizard::getListTerminated(bool bSuccess)
if(bSuccess)
{
m_pOutput->setText(__tr2qs("File downloaded: processing ..."));
- m_pOutput->tqrepaint();
+ m_pOutput->repaint();
#ifndef COMPILE_ON_WINDOWS
g_pApp->syncX();
#endif //!COMPILE_ON_WINDOWS
@@ -252,7 +252,7 @@ void KviRemoteMircServerImportWizard::getListTerminated(bool bSuccess)
TQString tmp;
if(iCount > 0)
- tmp = __tr2qs("%1 servers imported succesfully").tqarg(iCount);
+ tmp = __tr2qs("%1 servers imported succesfully").arg(iCount);
else
tmp = __tr2qs("No servers imported");
m_pOutput->setText(tmp);
diff --git a/src/modules/notifier/notifierwindow.cpp b/src/modules/notifier/notifierwindow.cpp
index 3a7568b..bbc1298 100644
--- a/src/modules/notifier/notifierwindow.cpp
+++ b/src/modules/notifier/notifierwindow.cpp
@@ -1191,7 +1191,7 @@ void KviNotifierWindow::redrawWindow()
}
inline void KviNotifierWindow::setCursor(int cur) {
- if (m_cursor.tqshape() != cur) {
+ if (m_cursor.shape() != cur) {
if(TQApplication::overrideCursor()) TQApplication::restoreOverrideCursor();
m_cursor.setShape((Qt::CursorShape)cur);
TQApplication::setOverrideCursor(m_cursor);
diff --git a/src/modules/objects/class_buttongroup.cpp b/src/modules/objects/class_buttongroup.cpp
index 9f6e26a..0a4f58a 100644
--- a/src/modules/objects/class_buttongroup.cpp
+++ b/src/modules/objects/class_buttongroup.cpp
@@ -48,7 +48,7 @@
@description:
This widget organizes buttons in a group.
It will be usually a parent for other child controls.
- You can either use a child tqlayout to manage the tqchildren geometries
+ You can either use a child tqlayout to manage the children geometries
or use $setColumnLayout function to manage the tqlayout automatically.
The class ineriths groupbox.
diff --git a/src/modules/objects/class_dockwindow.cpp b/src/modules/objects/class_dockwindow.cpp
index 40fc473..852db9d 100644
--- a/src/modules/objects/class_dockwindow.cpp
+++ b/src/modules/objects/class_dockwindow.cpp
@@ -50,7 +50,7 @@
@description:
A window dockable to the KVIrc main frame borders (like a toolbar).
The window has an implicit tqlayout that will automatically manage
- the tqchildren depending on the dock window's orientation.
+ the children depending on the dock window's orientation.
@functions:
!fn: $addWidget()
Adds to the internal tqlayout of this dock window.[br]
diff --git a/src/modules/objects/class_hbox.cpp b/src/modules/objects/class_hbox.cpp
index 58c518c..0f6ae24 100644
--- a/src/modules/objects/class_hbox.cpp
+++ b/src/modules/objects/class_hbox.cpp
@@ -35,11 +35,11 @@
@type:
class
@short:
- Manages child widget horizontal tqgeometry
+ Manages child widget horizontal geometry
@inherits:
[class]object[/class]
@description:
- The hbox class widget provides horizontal tqgeometry management for its child widgets.
+ The hbox class widget provides horizontal geometry management for its child widgets.
@functions:
!fn: $setSpacing()
Sets the default spacing of the widgets in pixels
diff --git a/src/modules/objects/class_label.cpp b/src/modules/objects/class_label.cpp
index 580f93b..f0e93e2 100644
--- a/src/modules/objects/class_label.cpp
+++ b/src/modules/objects/class_label.cpp
@@ -34,7 +34,7 @@
-// Tables used in $setAlignment & $tqalignment
+// Tables used in $setAlignment & $alignment
const char * const align_tbl[] = {
"Left",
"Right",
@@ -120,7 +120,7 @@ const int frame_cod[] = {
[class]widget[/class]
@description:
This widget can be used to display a text or an image. It can
- have different frame styles and text/image tqalignment.
+ have different frame styles and text/image alignment.
@functions:
!fn: $setText()
Sets the text to be displayed by the label.
@@ -144,15 +144,15 @@ const int frame_cod[] = {
automagically resize itself accordingly to the 'size' of the
text it contains.
See also [classfnc]$autoResize[/classfnc]().
- !fn: $tqalignment()
- Returns a string containing tqalignment flags that are set for
+ !fn: $alignment()
+ Returns a string containing alignment flags that are set for
this label. The flags are separated by commas. An example output
could look like this:[br]
[pre]Bottom, Right[/pre][br]
See [classfnc]$setAlignment[/classfnc]() for explanation of all
- tqalignment flags.
+ alignment flags.
!fn: $setAlignment(, , ...)
- This function sets tqalignment flags, given as parameters, for
+ This function sets alignment flags, given as parameters, for
this label. Valid flags are:
[pre]
Right - Text is aligned to right border[br]
@@ -179,8 +179,8 @@ const int frame_cod[] = {
frame-style flags and their explenation.
!fn: $setFrameStyle(, , ...)
Sets the frame-style flags to the ones passed as arguments.
- The flags can either decide of the tqshape or shadow of the
- label's frame. Valid tqshape flags are:[br]
+ The flags can either decide of the shape or shadow of the
+ label's frame. Valid shape flags are:[br]
[pre]
NoFrame - draw no frame. You shouldn't specify a shadow when
using this.[br]
@@ -216,7 +216,7 @@ KVSO_BEGIN_REGISTERCLASS(KviKvsObject_label,"label","widget")
KVSO_REGISTER_HANDLER(KviKvsObject_label,"setMargin", functionSetMargin)
KVSO_REGISTER_HANDLER(KviKvsObject_label,"autoResize", functionAutoResize)
KVSO_REGISTER_HANDLER(KviKvsObject_label,"setAutoResize", functionSetAutoResize)
- KVSO_REGISTER_HANDLER(KviKvsObject_label,"tqalignment", functionAlignment)
+ KVSO_REGISTER_HANDLER(KviKvsObject_label,"alignment", functionAlignment)
KVSO_REGISTER_HANDLER(KviKvsObject_label,"setAlignment", functionSetAlignment)
KVSO_REGISTER_HANDLER(KviKvsObject_label,"clear", functionClear)
KVSO_REGISTER_HANDLER(KviKvsObject_label,"frameStyle", functionFrameStyle)
@@ -297,13 +297,13 @@ bool KviKvsObject_label::functionAutoResize(KviKvsObjectFunctionCall *c)
//
bool KviKvsObject_label::functionSetAlignment(KviKvsObjectFunctionCall *c)
{
- TQStringList tqalignment;
+ TQStringList alignment;
KVSO_PARAMETERS_BEGIN(c)
- KVSO_PARAMETER("tqalignment",KVS_PT_STRINGLIST,KVS_PF_OPTIONAL,tqalignment)
+ KVSO_PARAMETER("alignment",KVS_PT_STRINGLIST,KVS_PF_OPTIONAL,alignment)
KVSO_PARAMETERS_END(c)
if (!widget()) return true;
int align,sum=0;
- for ( TQStringList::Iterator it = tqalignment.begin(); it != tqalignment.end(); ++it )
+ for ( TQStringList::Iterator it = alignment.begin(); it != alignment.end(); ++it )
{
align = 0;
@@ -318,7 +318,7 @@ bool KviKvsObject_label::functionSetAlignment(KviKvsObjectFunctionCall *c)
if(align)
sum = sum | align;
else
- c->warning(__tr2qs("Unknown tqalignment: '%Q'"),&(*it));
+ c->warning(__tr2qs("Unknown alignment: '%Q'"),&(*it));
}
((TQLabel *)widget())->setAlignment(sum);
@@ -326,7 +326,7 @@ bool KviKvsObject_label::functionSetAlignment(KviKvsObjectFunctionCall *c)
}
bool KviKvsObject_label::functionAlignment(KviKvsObjectFunctionCall *c)
{
- int mode = ((TQLabel *)widget())->tqalignment();
+ int mode = ((TQLabel *)widget())->alignment();
TQString szAlignment="";
for(unsigned int i = 0; i < align_num; i++)
{
diff --git a/src/modules/objects/class_layout.cpp b/src/modules/objects/class_layout.cpp
index 4381416..5caac1d 100644
--- a/src/modules/objects/class_layout.cpp
+++ b/src/modules/objects/class_layout.cpp
@@ -48,11 +48,11 @@
@type:
class
@short:
- Manages child widget tqgeometry
+ Manages child widget geometry
@inherits:
[class]object[/class]
@description:
- The tqlayout is a tqgeometry management tool for child widgets.
+ The tqlayout is a geometry management tool for child widgets.
You create a tqlayout , give it some widgets to manage and it will tqlayout them
automatically.[br]
The parent of the tqlayout must be the widget for which child widget geometries have to be managed.
diff --git a/src/modules/objects/class_listview.cpp b/src/modules/objects/class_listview.cpp
index 1bfe95a..f21417c 100644
--- a/src/modules/objects/class_listview.cpp
+++ b/src/modules/objects/class_listview.cpp
@@ -55,7 +55,7 @@
[class]widget[/class]
@description:
It can display and control a hierarchy of multi-column items, and provides the ability to add new items at any time.
- The items are added by creating tqchildren [class]listviewitem[/class] objects: simply allocating them with $new
+ The items are added by creating children [class]listviewitem[/class] objects: simply allocating them with $new
will add the items to the listview and simply deleting them will remove them.
Allocating a [class]listviewitem[/class] item2 as a child of item1 will insert it to the same listview creating
a subtree of items spannig from item1. The subtree can be opened or closed by a simple click either
@@ -132,11 +132,11 @@
The default implementation emits the [classfnc]$onItem[/classfnc]() signal.
!fn: $itemExpandedEvent()
- This event is called when an item has been expanded, i.e. when the tqchildren of item are shown.
+ This event is called when an item has been expanded, i.e. when the children of item are shown.
The default implementation emits the [classfnc]$expanded[/classfnc]() signal.
!fn: $itemCollapsedEvent()
- This event is called when an item has been collapsed, i.e. when the tqchildren of item are hidden.
+ This event is called when an item has been collapsed, i.e. when the children of item are hidden.
The default implementation emits the [classfnc]$collapsed[/classfnc]() signal.
!fn: $itemRenamedEvent(,,)
diff --git a/src/modules/objects/class_listviewitem.cpp b/src/modules/objects/class_listviewitem.cpp
index 49c448e..605fcee 100644
--- a/src/modules/objects/class_listviewitem.cpp
+++ b/src/modules/objects/class_listviewitem.cpp
@@ -71,7 +71,7 @@
Returns $true if this item is enabled and $false otherwise
!fn: $setOpen()
- Opens or closes the item to show its tqchildren items
+ Opens or closes the item to show its children items
!fn: $isOpen()
Returns the open state of this item
@@ -80,7 +80,7 @@
Makes this item checkable or not. This function should be called immediately
after the item creation: changing this property later at runtime may have
strange results (like the item being moved inside the list, text disappearing,
- hidden tqchildren etc... don't do it :D ).
+ hidden children etc... don't do it :D ).
!fn: $isCheckable()
Returns $true if this item is checkable and $false otherwise
@@ -94,7 +94,7 @@
have been previously called.
!fn: $firstChild()
- Returns the first child item of this listviewitem or $null if this item has no tqchildren.
+ Returns the first child item of this listviewitem or $null if this item has no children.
!fn: $nextSibling()
Returns the next sibling item of this listviewitem or $null if there are no sibling items.
diff --git a/src/modules/objects/class_multilineedit.cpp b/src/modules/objects/class_multilineedit.cpp
index 70d5086..1d14fcb 100644
--- a/src/modules/objects/class_multilineedit.cpp
+++ b/src/modules/objects/class_multilineedit.cpp
@@ -226,15 +226,15 @@ static int mod_cod[] = {
Returns 1(TRUE) if undo is available; otherwise returns 0(FALSE).
!fn: $isRedoAvailable ()
Returns 1(TRUE) if redo is available; otherwise returns 0(FALSE).
- !fn: $setAlignment()
- Sets the tqalignment of the current paragraph to . Valid values are:[br]
+ !fn: $setAlignment()
+ Sets the alignment of the current paragraph to . Valid values are:[br]
- AlignAuto - Aligns according to the language.[br]
- TQt::AlignLeft - Aligns with the left edge.[br]
- TQt::AlignRight - Aligns with the right edge.[br]
- TQt::AlignCenter - Centers in both dimensions.
- !fn: $setVerticalAlignment()
- Sets the vertical tqalignment of the current format to . Valid Values are:[br]
- - AlignNormal - Normal tqalignment.[br]
+ !fn: $setVerticalAlignment()
+ Sets the vertical alignment of the current format to . Valid Values are:[br]
+ - AlignNormal - Normal alignment.[br]
- AlignSuperScript - Superscript.[br]
- AlignSubScript - Subscript.
!fn: $setAutoFormatting()
@@ -1095,7 +1095,7 @@ bool KviKvsObject_mledit::functionsetAlignment(KviKvsObjectFunctionCall *c)
{
TQString szAlignment;
KVSO_PARAMETERS_BEGIN(c)
- KVSO_PARAMETER("tqalignment",KVS_PT_STRING,0,szAlignment)
+ KVSO_PARAMETER("alignment",KVS_PT_STRING,0,szAlignment)
KVSO_PARAMETERS_END(c)
if(!widget()) return true;
if(KviTQString::equalCI(szAlignment,"Left"))
@@ -1106,7 +1106,7 @@ bool KviKvsObject_mledit::functionsetAlignment(KviKvsObjectFunctionCall *c)
((KviTalMultiLineEdit *)widget())->setAlignment(TQt::AlignCenter);
else if(KviTQString::equalCI(szAlignment,"Justify"))
((KviTalMultiLineEdit *)widget())->setAlignment(TQt::AlignJustify);
- else c->warning(__tr2qs("Unknown tqalignment '%Q'"),&szAlignment);
+ else c->warning(__tr2qs("Unknown alignment '%Q'"),&szAlignment);
return true;
}
@@ -1131,18 +1131,18 @@ bool KviKvsObject_mledit::functionsetAutoFormatting(KviKvsObjectFunctionCall *c)
bool KviKvsObject_mledit::functionsetVerticalAlignment(KviKvsObjectFunctionCall *c)
{
- TQString szVtqalignment;
+ TQString szValignment;
KVSO_PARAMETERS_BEGIN(c)
- KVSO_PARAMETER("tqalignment",KVS_PT_STRING,0,szVtqalignment)
+ KVSO_PARAMETER("alignment",KVS_PT_STRING,0,szValignment)
KVSO_PARAMETERS_END(c)
if(!widget()) return true;
- if(KviTQString::equalCI(szVtqalignment,"Normal"))
+ if(KviTQString::equalCI(szValignment,"Normal"))
((KviTalMultiLineEdit *)widget())->setVerticalAlignment(KviTalMultiLineEdit::AlignNormal);
- else if(KviTQString::equalCI(szVtqalignment,"SuperScript"))
+ else if(KviTQString::equalCI(szValignment,"SuperScript"))
((KviTalMultiLineEdit *)widget())->setVerticalAlignment(KviTalMultiLineEdit::AlignSuperScript);
- else if(KviTQString::equalCI(szVtqalignment,"SubScript"))
+ else if(KviTQString::equalCI(szValignment,"SubScript"))
((KviTalMultiLineEdit *)widget())->setVerticalAlignment(KviTalMultiLineEdit::AlignSubScript);
- else c->warning(__tr2qs("Unknown vertical tqalignment '%Q'"),&szVtqalignment);
+ else c->warning(__tr2qs("Unknown vertical alignment '%Q'"),&szValignment);
return true;
}
diff --git a/src/modules/objects/class_painter.cpp b/src/modules/objects/class_painter.cpp
index 826d119..81cc3f6 100644
--- a/src/modules/objects/class_painter.cpp
+++ b/src/modules/objects/class_painter.cpp
@@ -41,12 +41,12 @@
@type:
class
@short:
- This class provide a painter to paint line and tqshapes.
+ This class provide a painter to paint line and shapes.
@inherits:
[class]object[/class]
[class]widget[/class]
@description:
- With this class you can draw many graphics objects from simple lines to complex tqshapes like pies and chords.[br]
+ With this class you can draw many graphics objects from simple lines to complex shapes like pies and chords.[br]
It can also draw aligned text and pixmaps. Normally, it draws in a "natural" coordinate system, but it can also do view and world transformation.[br]
The class need to be implemented into a [classfnc]$paintEvent[/classfnc]();
@functions:
@@ -196,8 +196,8 @@
timerevent()[br]
{[br]
$$->%b = $(($$->%b + 1) & 15);[br]
- if ($$->%nextanim == 1) $$->$tqrepaint(1);[br]
- $$->$tqrepaint(0);[br]
+ if ($$->%nextanim == 1) $$->$repaint(1);[br]
+ $$->$repaint(0);[br]
}[br]
drawAnim()[br]
{[br]
@@ -414,12 +414,12 @@ if(__pXOrArray->isArray())\
KviKvsVariant * pH = __pXOrArray->array()->at(3);\
if(!(pX && pY && pW && pH))\
{\
- c->error(__tr2qs("One of the tqgeometry array parameters is empty"));\
+ c->error(__tr2qs("One of the geometry array parameters is empty"));\
return false;\
}\
if(!(pX->asInteger(iX) && pY->asInteger(__iY) && pW->asInteger(__iW) && pH->asInteger(__iH)))\
{\
- c->error(__tr2qs("One of the tqgeometry array parameters didn't evaluate to an integer"));\
+ c->error(__tr2qs("One of the geometry array parameters didn't evaluate to an integer"));\
return false;\
}\
} else {\
diff --git a/src/modules/objects/class_tabwidget.cpp b/src/modules/objects/class_tabwidget.cpp
index d30a6b6..fc22188 100644
--- a/src/modules/objects/class_tabwidget.cpp
+++ b/src/modules/objects/class_tabwidget.cpp
@@ -129,10 +129,10 @@
%labelwp=$new(label,%secondtab)
%labelwp->$settext("Enjoy the new Class provided by")
%layoutsecondtab->$addwidget(%labelwp,0,0)
- %labelwp->$settqalignment("Center")
+ %labelwp->$setalignment("Center")
%labelgen=$new(label,%secondtab)
%labelgen->$settext(Grifisx \& Noldor)
- %labelgen->$settqalignment("Center")
+ %labelgen->$setalignment("Center")
%layoutsecondtab->$addwidget(%labelgen,1,0)
%Tabwidget->$addTab(%secondtab,&About,50)
diff --git a/src/modules/objects/class_urllabel.cpp b/src/modules/objects/class_urllabel.cpp
index 639b311..2d0416b 100644
--- a/src/modules/objects/class_urllabel.cpp
+++ b/src/modules/objects/class_urllabel.cpp
@@ -152,7 +152,7 @@ bool KviScriptUrlLabelObject::eventFilter(TQObject * o, TQEvent * e)
!fn: $setText()
Sets the label's text. Reimplemented from internal reasons.
!fn: $setCursorChange()
- Tells the label wheather to change or not the tqshape of cursor,
+ Tells the label wheather to change or not the shape of cursor,
when it is above the widget. Default is false.
!fn: $cursorChange()
Returns true if the cursor changes over the label, false if not.
diff --git a/src/modules/objects/class_vbox.cpp b/src/modules/objects/class_vbox.cpp
index d068156..bfc8014 100644
--- a/src/modules/objects/class_vbox.cpp
+++ b/src/modules/objects/class_vbox.cpp
@@ -35,11 +35,11 @@
@type:
class
@short:
- Manages child widget vertical tqgeometry
+ Manages child widget vertical geometry
@inherits:
[class]object[/class]
@description:
- The vbox class widget provides vertical tqgeometry management for its child widgets.
+ The vbox class widget provides vertical geometry management for its child widgets.
@functions:
!fn: $setSpacing()
Sets the default spacing of the widgets in pixels
diff --git a/src/modules/objects/class_widget.h b/src/modules/objects/class_widget.h
index edbe610..47d13cd 100644
--- a/src/modules/objects/class_widget.h
+++ b/src/modules/objects/class_widget.h
@@ -59,7 +59,7 @@ protected:
bool function_fontMetricsHeight(KviKvsObjectFunctionCall * c);
bool function_fontMetricsWidth(KviKvsObjectFunctionCall * c);
bool function_foregroundColor(KviKvsObjectFunctionCall *c);
- bool function_tqgeometry(KviKvsObjectFunctionCall *c);
+ bool function_geometry(KviKvsObjectFunctionCall *c);
bool function_globalCursorX(KviKvsObjectFunctionCall *c);
bool function_globalCursorY(KviKvsObjectFunctionCall *c);
bool function_hasFocus(KviKvsObjectFunctionCall *c);
@@ -74,7 +74,7 @@ protected:
bool function_move(KviKvsObjectFunctionCall *c);
bool function_parentWidget(KviKvsObjectFunctionCall *c);
bool function_raise(KviKvsObjectFunctionCall *);
- bool function_tqrepaint(KviKvsObjectFunctionCall *c);
+ bool function_repaint(KviKvsObjectFunctionCall *c);
bool function_reparent(KviKvsObjectFunctionCall *c);
bool function_resize(KviKvsObjectFunctionCall *c);
bool function_screenResolution(KviKvsObjectFunctionCall * c);
diff --git a/src/modules/objects/class_window.cpp b/src/modules/objects/class_window.cpp
index 393c296..918f541 100644
--- a/src/modules/objects/class_window.cpp
+++ b/src/modules/objects/class_window.cpp
@@ -119,7 +119,7 @@ bool KviKvsObject_window::init(KviKvsRunTimeContext * pContext,KviKvsVariantList
KviWindow * w = new KviKvsScriptWindowWindow(pContext->window()->frame(),name());
setObject(TQT_TQOBJECT(w));
pContext->window()->frame()->addWindow(w,false);
- w->minimize(); // must be minimized before tqchildren are added, otherwise the focus handling goes nuts...
+ w->minimize(); // must be minimized before children are added, otherwise the focus handling goes nuts...
return true;
}
diff --git a/src/modules/objects/class_wrapper.cpp b/src/modules/objects/class_wrapper.cpp
index 928ddaf..38901ed 100644
--- a/src/modules/objects/class_wrapper.cpp
+++ b/src/modules/objects/class_wrapper.cpp
@@ -72,7 +72,7 @@
The first entry in this example is a KVIrc server window, class "KviFrame" and name "kvirc_frame":
it is a toplevel widget.[br]
The "qt_top_dock", "qt_custom_toolbar" and the "qt_dockwidget_internal" are
- direct tqchildren of that widget.[br]
+ direct children of that widget.[br]
To indicate a specific widget we will use the "class::name" form.[br]
So to indicate the main KVIrc frame you will use "KviFrame::kvirc_main_frame".
Look at this example:[br]
diff --git a/src/modules/objects/libkviobjects.cpp b/src/modules/objects/libkviobjects.cpp
index 3a939ff..2a4dc9d 100644
--- a/src/modules/objects/libkviobjects.cpp
+++ b/src/modules/objects/libkviobjects.cpp
@@ -153,7 +153,7 @@ static bool objects_kvs_cmd_killClass(KviKvsModuleCommandCall * c)
Suppresses any warning message
@description:
Removes the definition of the class .[br]
- All the instances of the class are killed (thus tqchildren objects are killed too).[br]
+ All the instances of the class are killed (thus children objects are killed too).[br]
All the derived class definitions are removed as well.[br]
Builtin class definitions cannot be removed and this commands
kills only all the instances of that class (derived class definitions
@@ -913,7 +913,7 @@ static bool objects_kvs_fnc_listObjects(KviKvsModuleFunctionCall * cmd)
static void dumpChildObjects(KviWindow *pWnd, TQObject *parent, const char *spacing, bool bFlag, KviKvsArray *n, int &idx)
{
#ifdef COMPILE_USE_QT4
- const TQObjectList list = parent->tqchildren();
+ const TQObjectList list = parent->children();
if( !list.count() ) return;
TQString sp(spacing);
sp.append(">");
diff --git a/src/modules/options/dialog.cpp b/src/modules/options/dialog.cpp
index 107c597..4f1dedf 100644
--- a/src/modules/options/dialog.cpp
+++ b/src/modules/options/dialog.cpp
@@ -179,7 +179,7 @@ KviOptionsDialog::KviOptionsDialog(TQWidget * par,const TQString &szGroup)
"" \
"" \
" "
- ).tqarg(szDialogTitle).tqarg(szDialog).tqarg(szInfoTips).tqarg(szOkCancelButtons);
+ ).arg(szDialogTitle).arg(szDialog).arg(szInfoTips).arg(szOkCancelButtons);
TQString szCaption = szDialogTitle + " - KVIrc";
setCaption(szCaption);
@@ -534,10 +534,10 @@ void KviOptionsDialog::fillListView(KviTalListViewItem * p,KviPointerListbIsContainer)
{
- // it's a container: add only eventual not contained tqchildren (containers or explicitly marked as not contained)
+ // it's a container: add only eventual not contained children (containers or explicitly marked as not contained)
fillListView(it,e->pChildList,szGroup,true);
} else {
- // it's not a container, add any tqchildren
+ // it's not a container, add any children
fillListView(it,e->pChildList,szGroup,false);
}
}
@@ -578,7 +578,7 @@ KviOptionsListViewItem * KviOptionsDialog::findItemByPage(KviOptionsListViewItem
if(it->m_pOptionsWidget == pPage)return it;
KviOptionsListViewItem *i;
- // run through the tqchildren
+ // run through the children
i = (KviOptionsListViewItem *)(it->firstChild());
if(i)
{
@@ -586,7 +586,7 @@ KviOptionsListViewItem * KviOptionsDialog::findItemByPage(KviOptionsListViewItem
if(i)return i;
}
- // not found in the tqchildren tree.. look in the next sibling
+ // not found in the children tree.. look in the next sibling
i = (KviOptionsListViewItem *)(it->nextSibling());
if(i)
{
@@ -647,7 +647,7 @@ void KviOptionsDialog::closeEvent(TQCloseEvent *e)
void KviOptionsDialog::recursiveCommit(KviOptionsListViewItem *it)
{
- // First commit the tqchildren
+ // First commit the children
if(!it) return;
KviOptionsListViewItem *it2 = (KviOptionsListViewItem *)it->firstChild();
while(it2)
diff --git a/src/modules/options/mkcreateinstanceproc.sh b/src/modules/options/mkcreateinstanceproc.sh
index 1a25a14..9947aff 100755
--- a/src/modules/options/mkcreateinstanceproc.sh
+++ b/src/modules/options/mkcreateinstanceproc.sh
@@ -271,7 +271,7 @@ printclass()
fi
}
-addtqchildren()
+addchildren()
{
if [ -f "$CLASSDIR/$2" ]; then
LEVEL=`cat $CLASSDIR/$2`
@@ -282,7 +282,7 @@ addtqchildren()
echo "$3 e$1->pChildList = new KviPointerList;" >> $TARGET
echo "$3 e$1->pChildList->setAutoDelete(true);" >> $TARGET
NEXTLEVEL=`expr $1 + 1`
- addtqchildren $NEXTLEVEL $achild "$3 "
+ addchildren $NEXTLEVEL $achild "$3 "
else
echo "$3 e$1->pChildList = 0;" >> $TARGET
fi
@@ -290,7 +290,7 @@ addtqchildren()
fi
}
-addtqchildren 0 NOPARENT ""
+addchildren 0 NOPARENT ""
rm -fr $CLASSDIR
diff --git a/src/modules/options/optw_irc.cpp b/src/modules/options/optw_irc.cpp
index f39add0..a6cee9d 100644
--- a/src/modules/options/optw_irc.cpp
+++ b/src/modules/options/optw_irc.cpp
@@ -181,7 +181,7 @@ KviChannelAdvancedOptionsWidget::KviChannelAdvancedOptionsWidget(TQWidget * pPar
hostmask.mask(tmp1,(KviIrcMask::MaskType)i);
ipmask.mask(tmp2,(KviIrcMask::MaskType)i);
- m_pBanTypeCombo->insertItem(TQString("%1 (%2)").tqarg(tmp1).tqarg(tmp2));
+ m_pBanTypeCombo->insertItem(TQString("%1 (%2)").arg(tmp1).arg(tmp2));
}
m_pBanTypeCombo->setCurrentItem(KVI_OPTION_UINT(KviOption_uintDefaultBanType));
diff --git a/src/modules/options/optw_servers.cpp b/src/modules/options/optw_servers.cpp
index 309344c..2c26ac5 100644
--- a/src/modules/options/optw_servers.cpp
+++ b/src/modules/options/optw_servers.cpp
@@ -732,7 +732,7 @@ KviServerDetailsWidget::KviServerDetailsWidget(TQWidget * par,KviIrcServer * s)
KviPointerList * proxylist = g_pProxyDataBase->proxyList();
for(KviProxy * p = proxylist->first();p;p = proxylist->next())
{
- m_pProxyEditor->insertItem(TQString("%1:%2").tqarg(p->hostname()).tqarg(p->port()));
+ m_pProxyEditor->insertItem(TQString("%1:%2").arg(p->hostname()).arg(p->port()));
}
if(m_pProxyEditor->count() > (s->proxy()+2))
m_pProxyEditor->setCurrentItem(s->proxy()+2);
diff --git a/src/modules/options/optw_textencoding.cpp b/src/modules/options/optw_textencoding.cpp
index 495df00..fc915ed 100644
--- a/src/modules/options/optw_textencoding.cpp
+++ b/src/modules/options/optw_textencoding.cpp
@@ -68,7 +68,7 @@ KviTextEncodingOptionsWidget::KviTextEncodingOptionsWidget(TQWidget * parent)
m_pForcedLocaleCombo->insertItem(__tr2qs_ctx("Automatic detection","options"));
m_pForcedLocaleCombo->insertItem(__tr2qs_ctx("en","options"));
- TQString szLangFile=TQString("%1/.kvirc_force_locale").tqarg(TQDir::homeDirPath());
+ TQString szLangFile=TQString("%1/.kvirc_force_locale").arg(TQDir::homeDirPath());
bool bIsDefaultLocale = !KviFileUtils::fileExists(szLangFile);
//We Have setted locale, but not restarted kvirc
@@ -121,7 +121,7 @@ void KviTextEncodingOptionsWidget::commit()
}
idx=m_pForcedLocaleCombo->currentItem();
- TQString szLangFile=TQString("%1/.kvirc_force_locale").tqarg(TQDir::homeDirPath());
+ TQString szLangFile=TQString("%1/.kvirc_force_locale").arg(TQDir::homeDirPath());
if(idx==0) {
if(KviFileUtils::fileExists(szLangFile))
KviFileUtils::removeFile(szLangFile);
diff --git a/src/modules/reguser/dialog.cpp b/src/modules/reguser/dialog.cpp
index 59fc732..254c5fe 100644
--- a/src/modules/reguser/dialog.cpp
+++ b/src/modules/reguser/dialog.cpp
@@ -312,7 +312,7 @@ KviRegisteredUsersDialog::~KviRegisteredUsersDialog()
if(!parent())KVI_OPTION_RECT(KviOption_rectRegisteredUsersDialogGeometry) = TQRect(pos().x(),pos().y(),
size().width(),size().height());
#else
- if(!parent())KVI_OPTION_RECT(KviOption_rectRegisteredUsersDialogGeometry) = tqgeometry();
+ if(!parent())KVI_OPTION_RECT(KviOption_rectRegisteredUsersDialogGeometry) = geometry();
#endif
g_pRegisteredUsersDialog = 0;
diff --git a/src/modules/setup/setupwizard.cpp b/src/modules/setup/setupwizard.cpp
index b0c72cf..1a8b5c4 100644
--- a/src/modules/setup/setupwizard.cpp
+++ b/src/modules/setup/setupwizard.cpp
@@ -736,7 +736,7 @@ void KviSetupWizard::chooseOldDataPath()
__tr2qs("Do not overwrite folder? - KVIrc"),
tqtr("A folder %1 seems to be not a valid KVIrc settings folder."
"Do you want to use it anyway?")
- .tqarg( szBuffer ),
+ .arg( szBuffer ),
__tr2qs("&Yes"), __tr2qs("&No"),
TQString(), 0, 1 ) == 0
) {
@@ -1005,7 +1005,7 @@ void KviSetupWizard::accept()
#ifndef COMPILE_ON_WINDOWS
// Make local->global link
- TQString localPath = TQString("%1/global").tqarg(g_pApp->m_szLocalKvircDir);
+ TQString localPath = TQString("%1/global").arg(g_pApp->m_szLocalKvircDir);
unlink(TQTextCodec::codecForLocale()->fromUnicode(localPath).data());
symlink(TQTextCodec::codecForLocale()->fromUnicode(g_pApp->m_szGlobalKvircDir).data(),TQTextCodec::codecForLocale()->fromUnicode(localPath).data());
#endif
diff --git a/src/modules/sharedfileswindow/sharedfileswindow.cpp b/src/modules/sharedfileswindow/sharedfileswindow.cpp
index c8aa9e4..11e320d 100644
--- a/src/modules/sharedfileswindow/sharedfileswindow.cpp
+++ b/src/modules/sharedfileswindow/sharedfileswindow.cpp
@@ -411,7 +411,7 @@ void KviSharedFilesWindow::rightButtonPressed(KviTalListViewItem *it,const TQPoi
if(fi.exists())
{
tmp += "";
- tmp += __tr2qs_ctx("Size: %1 bytes","filetransferwindow").tqarg(fi.size());
+ tmp += __tr2qs_ctx("Size: %1 bytes","filetransferwindow").arg(fi.size());
tmp += " ";
}
diff --git a/src/modules/theme/packthemedialog.cpp b/src/modules/theme/packthemedialog.cpp
index 6f2e24c..269fbfe 100644
--- a/src/modules/theme/packthemedialog.cpp
+++ b/src/modules/theme/packthemedialog.cpp
@@ -293,7 +293,7 @@ KviPackThemeDialog::KviPackThemeDialog(TQWidget * pParent,KviPointerListsetText(__tr2qs_ctx("Here you must choose the file name for the theme package. It should have a *.%1 extension.","theme").tqarg(KVI_FILEEXTENSION_THEMEPACKAGE));
+ pLabel->setText(__tr2qs_ctx("Here you must choose the file name for the theme package. It should have a *.%1 extension.","theme").arg(KVI_FILEEXTENSION_THEMEPACKAGE));
pLabel->setTextFormat(TQt::RichText);
pLayout->addWidget(pLabel,0,0);
diff --git a/src/modules/toolbareditor/toolbareditor.cpp b/src/modules/toolbareditor/toolbareditor.cpp
index 927fbf7..208c269 100644
--- a/src/modules/toolbareditor/toolbareditor.cpp
+++ b/src/modules/toolbareditor/toolbareditor.cpp
@@ -371,7 +371,7 @@ void KviCustomizeToolBarsDialog::deleteToolBar()
if(!t)return;
if(TQMessageBox::question(this,
__tr2qs("Confirm ToolBar Deletion"),
- __tr2qs("Do you really want to delete toolbar \"%1\" ?").tqarg(t->label()),
+ __tr2qs("Do you really want to delete toolbar \"%1\" ?").arg(t->label()),
__tr2qs("No"),
__tr2qs("Yes")) == 0)return;
KviCustomToolBarManager::instance()->destroyDescriptor(t->descriptor()->id());
@@ -462,7 +462,7 @@ void KviCustomizeToolBarsDialog::renameToolBar()
if(!t)return;
KviCustomToolBarPropertiesDialog * dlg = new KviCustomToolBarPropertiesDialog(this,
- __tr2qs("Please specify the properties for the toolbar \"%1\"").tqarg(t->label()),
+ __tr2qs("Please specify the properties for the toolbar \"%1\"").arg(t->label()),
t->descriptor()->id(),
t->descriptor()->labelCode(),
t->descriptor()->iconId());
diff --git a/src/modules/torrent/tc_statusbarapplet.cpp b/src/modules/torrent/tc_statusbarapplet.cpp
index 45b32db..e8b6528 100644
--- a/src/modules/torrent/tc_statusbarapplet.cpp
+++ b/src/modules/torrent/tc_statusbarapplet.cpp
@@ -39,12 +39,12 @@ void KviTorrentStatusBarApplet::selfRegister(KviStatusBar *bar)
TQString formatSize(float sz)
{
if (sz >= 1024.0f*1024.0f*1024.0f)
- return TQString("%1 GB").tqarg(sz / (1024.0f*1024.0f*1024.0f), 2, 'f', 2);
+ return TQString("%1 GB").arg(sz / (1024.0f*1024.0f*1024.0f), 2, 'f', 2);
if (sz >= 1024.0f*1024.0f)
- return TQString("%1 MB").tqarg(sz / (1024.0f*1024.0f), 2, 'f', 2);
+ return TQString("%1 MB").arg(sz / (1024.0f*1024.0f), 2, 'f', 2);
if (sz >= 1024.0f)
- return TQString("%1 KB").tqarg(sz / 1024.0f, 2, 'f', 2);
- return TQString("%1 B").tqarg(sz, 2, 'f', 2);
+ return TQString("%1 KB").arg(sz / 1024.0f, 2, 'f', 2);
+ return TQString("%1 B").arg(sz, 2, 'f', 2);
}
void KviTorrentStatusBarApplet::update()
@@ -52,10 +52,10 @@ void KviTorrentStatusBarApplet::update()
if (KviTorrentInterface::selected())
{
TQString msg = TQString("up: %1 K/s (%2), dn: %3 K/s (%4)")
- .tqarg(KviTorrentInterface::selected()->speedUp(), 2)
- .tqarg(formatSize(KviTorrentInterface::selected()->trafficUp()))
- .tqarg(KviTorrentInterface::selected()->speedDown(), 2)
- .tqarg(formatSize(KviTorrentInterface::selected()->trafficDown()));
+ .arg(KviTorrentInterface::selected()->speedUp(), 2)
+ .arg(formatSize(KviTorrentInterface::selected()->trafficUp()))
+ .arg(KviTorrentInterface::selected()->speedDown(), 2)
+ .arg(formatSize(KviTorrentInterface::selected()->trafficDown()));
setText(msg);
diff --git a/src/modules/url/libkviurl.cpp b/src/modules/url/libkviurl.cpp
index b3edd19..c0e647c 100644
--- a/src/modules/url/libkviurl.cpp
+++ b/src/modules/url/libkviurl.cpp
@@ -285,7 +285,7 @@ void UrlDialog::popup(KviTalListViewItem *item, const TQPoint &point, int col)
void UrlDialog::sayToWin(int itemID)
{
KviWindow *wnd = g_pApp->findWindowByCaption(m_pListPopup->text(itemID).utf8().data());
- TQString say=TQString("PRIVMSG %1 %2").tqarg(wnd->windowName()).tqarg(m_szUrl.ptr());
+ TQString say=TQString("PRIVMSG %1 %2").arg(wnd->windowName()).arg(m_szUrl.ptr());
if (wnd) {
KviKvsScript::run(say,wnd);
wnd->raise();
diff --git a/src/modules/window/libkviwindow.cpp b/src/modules/window/libkviwindow.cpp
index 7c83051..3624402 100644
--- a/src/modules/window/libkviwindow.cpp
+++ b/src/modules/window/libkviwindow.cpp
@@ -1499,7 +1499,7 @@ static bool window_module_init(KviModule *m)
// saveOutput (view()->saveBuffer())
/*
- m->registerFunction("geometry",window_module_fnc_tqgeometry);
+ m->registerFunction("geometry",window_module_fnc_geometry);
m->registerCommand("setGeometry",window_module_cmd_setGeometry);
m->registerFunction("isActive",window_module_fnc_isActive);
|
diff --git a/src/modules/objects/class_groupbox.cpp b/src/modules/objects/class_groupbox.cpp
index d0ecae0..a1f5c11 100644
--- a/src/modules/objects/class_groupbox.cpp
+++ b/src/modules/objects/class_groupbox.cpp
@@ -29,7 +29,7 @@
#include "kvi_locale.h"
#include "kvi_iconmanager.h"
-// Tables used in $setAlignment , $tqalignment and in $setOrientation & $orientation
+// Tables used in $setAlignment , $alignment and in $setOrientation & $orientation
const char * const align_tbl[] = {
"Left",
@@ -60,7 +60,7 @@ const int align_cod[] = {
@description:
This widget can be used to display a groupbox.
It will be usually a parent for other child controls.
- You can either use a child tqlayout to manage the tqchildren geometries
+ You can either use a child tqlayout to manage the children geometries
or use $setColumnLayout to manage the tqlayout automatically.
@functions:
!fn: $setTitle()
@@ -89,14 +89,14 @@ const int align_cod[] = {
Returns the number of columns or rows in the groupbox.
!fn: $addSpace()
Adds an empty cell at the next free position.
- !fn: $tqalignment()
- Returns the tqalignment of the group box title.
- !fn: $setAlignment()
- Set the tqalignment of the groupbox; Valid values are Left,Right,HCenter.
+ !fn: $alignment()
+ Returns the alignment of the group box title.
+ !fn: $setAlignment()
+ Set the alignment of the groupbox; Valid values are Left,Right,HCenter.
!fn: $setOrientation
Sets the group box's orientation. Valid values are:Qt::Horizontal,Qt::Vertical.
!fn: $setColumnLayout(,)
- Enables the automatic tqlayout management. The tqchildren are arranged in n columns with the specified orientation.[br]
+ Enables the automatic tqlayout management. The children are arranged in n columns with the specified orientation.[br]
Valid values for are:Qt::Horizontal,Qt::Vertical.
@examples:
[example]
@@ -137,8 +137,8 @@ const int align_cod[] = {
%layoutbtn->$addwidget(%btnok,0,0)[br]
%layoutbtn->$addwidget(%btncancel,0,1)[br]
[br]
#And finally we create a main tqlayout with the groupbox (and its "tqchildren")[br]
#and fakewiget (with its buttons tqchildren).
%maintqlayout=$new(tqlayout,%widget)[br]
%maintqlayout->$setspacing(10)[br]
%maintqlayout->$setmargin(10)[br]
@@ -165,7 +165,7 @@ KVSO_BEGIN_REGISTERCLASS(KviKvsObject_groupbox,"groupbox","widget")
KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"setColumns", functionSetColumns)
KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"columns", functionColumns)
KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"addSpace", functionAddSpace)
- KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"tqalignment", functionAlignment)
+ KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"alignment", functionAlignment)
KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"setAlignment", functionSetAlignment)
KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"setOrientation", functionSetOrientation)
KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"isChecked", functionIsChecked)
@@ -310,7 +310,7 @@ bool KviKvsObject_groupbox::functionSetAlignment(KviKvsObjectFunctionCall *c)
{
TQString szAlign;
KVSO_PARAMETERS_BEGIN(c)
- KVSO_PARAMETER("tqalignment",KVS_PT_STRING,0,szAlign)
+ KVSO_PARAMETER("alignment",KVS_PT_STRING,0,szAlign)
KVSO_PARAMETERS_END(c)
if (!widget()) return true;
for(unsigned int i = 0; i < align_num; i++)
@@ -321,12 +321,12 @@ bool KviKvsObject_groupbox::functionSetAlignment(KviKvsObjectFunctionCall *c)
return true;
}
}
- c->warning(__tr2qs("Unknown tqalignment"));
+ c->warning(__tr2qs("Unknown alignment"));
return true;
}
bool KviKvsObject_groupbox::functionAlignment(KviKvsObjectFunctionCall *c)
{
- int mode = ((KviTalGroupBox *)widget())->tqalignment();
+ int mode = ((KviTalGroupBox *)widget())->alignment();
TQString szAlignment="";
for(unsigned int i = 0; i < align_num; i++)
{
@@ -137,8 +137,8 @@ const int align_cod[] = {
%layoutbtn->$addwidget(%btncancel,0,1)[br]
[br]
- #And finally we create a main tqlayout with the groupbox (and its "tqchildren")[br]
- #and fakewiget (with its buttons tqchildren).
+ #And finally we create a main tqlayout with the groupbox (and its "children")[br]
+ #and fakewiget (with its buttons children).
%maintqlayout=$new(tqlayout,%widget)[br]
%maintqlayout->$setspacing(10)[br]
diff --git a/src/modules/objects/class_widget.cpp b/src/modules/objects/class_widget.cpp
index fec3925..83d5608 100644
--- a/src/modules/objects/class_widget.cpp
+++ b/src/modules/objects/class_widget.cpp
@@ -137,12 +137,12 @@ const int widgettypes_cod[] = {
All the other widget-type classes inherit from this one.
@functions:
!fn: $show()
- Shows this widget and the tqchildren.
+ Shows this widget and the children.
See also [classfnc]$hide[/classfnc]() and [classfnc]$isVisible[/classfnc].
!fn: $hide()
- Hides this widget (and conseguently all the tqchildren).
+ Hides this widget (and conseguently all the children).
See also [classfnc]$show[/classfnc]() and [classfnc]$isVisible[/classfnc].
- !fn: $tqrepaint()
+ !fn: $repaint()
Repaints the widget directly by calling [classfnc]$paintEvent[/classfnc]() immediately.[br]
If erase is TRUE, erases the widget before the $paintEvent() call.
!fn: $x()
@@ -157,11 +157,11 @@ const int widgettypes_cod[] = {
Returns the width of this widget in pixels.
!fn: $height()
Returns the height of this widget in pixels.
- !fn: $tqgeometry()
- Returns the widget tqgeometry in this form:[br]
+ !fn: $geometry()
+ Returns the widget geometry in this form:[br]
x, y, width, height.
!fn: $setGeometry(,[,,])
- Sets the tqgeometry of this widget. and are relative
+ Sets the geometry of this widget. and are relative
to the parent widget or to the desktop (if this widget is
a toplevel one). All the parameters are in pixels.
!fn: $setMinimumWidth()
@@ -341,7 +341,7 @@ const int widgettypes_cod[] = {
If a tooltip has setted with [classfnc]$setTooltip[/classfnc] the dynamic tooltip will be ignored.
The default implementation does nothing.
!fn: $paintEvent()
- This event handler can be reimplemented to tqrepaint all or part of the widget.
+ This event handler can be reimplemented to repaint all or part of the widget.
It's needed by the Painter class.
It's very useful for drawing flicker free animations or low level special graphic effects.
If you call "[cmd]return[/cmd] $true" you will stop the internal processing
@@ -522,7 +522,7 @@ const int widgettypes_cod[] = {
// ... now that I think about it , it
// may happen that widget() will be zero here too:
// If the TQt "physical" widget gets destroyed
// by some external factor (for example when tqchildren
// of a wrapper widget destroyed by KVIrc).
//
// as a convention:
@@ -546,7 +546,7 @@ KVSO_BEGIN_REGISTERCLASS(KviKvsObject_widget,"widget","object")
// apparence
KVSO_REGISTER_HANDLER(KviKvsObject_widget,"show",function_show)
KVSO_REGISTER_HANDLER(KviKvsObject_widget,"hide",function_hide)
- KVSO_REGISTER_HANDLER(KviKvsObject_widget,"tqrepaint",function_tqrepaint)
+ KVSO_REGISTER_HANDLER(KviKvsObject_widget,"repaint",function_repaint)
KVSO_REGISTER_HANDLER(KviKvsObject_widget,"isTopLevel",function_isTopLevel)
KVSO_REGISTER_HANDLER(KviKvsObject_widget,"isVisible",function_isVisible)
KVSO_REGISTER_HANDLER(KviKvsObject_widget,"raise",function_raise)
@@ -567,10 +567,10 @@ KVSO_BEGIN_REGISTERCLASS(KviKvsObject_widget,"widget","object")
KVSO_REGISTER_HANDLER(KviKvsObject_widget,"fontMetricsWidth",function_fontMetricsWidth)
KVSO_REGISTER_HANDLER(KviKvsObject_widget,"fontMetricsHeight",function_fontMetricsHeight)
KVSO_REGISTER_HANDLER(KviKvsObject_widget,"setFont",function_setFont)
- // tqgeometry
+ // geometry
KVSO_REGISTER_HANDLER(KviKvsObject_widget,"screenResolution",function_screenResolution)
KVSO_REGISTER_HANDLER(KviKvsObject_widget,"centerToScreen",function_centerToScreen)
- KVSO_REGISTER_HANDLER(KviKvsObject_widget,"geometry",function_tqgeometry)
+ KVSO_REGISTER_HANDLER(KviKvsObject_widget,"geometry",function_geometry)
KVSO_REGISTER_HANDLER(KviKvsObject_widget,"setGeometry",function_setGeometry)
KVSO_REGISTER_HANDLER(KviKvsObject_widget,"mapToGlobal",function_mapToGlobal)
KVSO_REGISTER_HANDLER(KviKvsObject_widget,"mapFromGlobal",function_mapFromGlobal)
@@ -916,14 +916,14 @@ bool KviKvsObject_widget::function_fontAscent(KviKvsObjectFunctionCall * c)
}
-bool KviKvsObject_widget::function_tqrepaint(KviKvsObjectFunctionCall * c)
+bool KviKvsObject_widget::function_repaint(KviKvsObjectFunctionCall * c)
{
bool bEnabled;
KVSO_PARAMETERS_BEGIN(c)
KVSO_PARAMETER("bEnabled",KVS_PT_BOOL,0,bEnabled)
KVSO_PARAMETERS_END(c)
if(!widget()) return true;
- widget()->tqrepaint(bEnabled);
+ widget()->repaint(bEnabled);
return true;
}
@@ -955,9 +955,9 @@ bool KviKvsObject_widget::function_screenResolution(KviKvsObjectFunctionCall * c
return true;
}
-bool KviKvsObject_widget::function_tqgeometry(KviKvsObjectFunctionCall *c)
+bool KviKvsObject_widget::function_geometry(KviKvsObjectFunctionCall *c)
{
- TQRect r = widget() ? widget()->tqgeometry() : TQRect(0,0,0,0);
+ TQRect r = widget() ? widget()->geometry() : TQRect(0,0,0,0);
KviKvsArray * a = new KviKvsArray();
a->set(0,new KviKvsVariant((kvs_int_t)r.x()));
a->set(1,new KviKvsVariant((kvs_int_t)r.y()));
@@ -992,7 +992,7 @@ bool KviKvsObject_widget::function_setGeometry(KviKvsObjectFunctionCall *c)
if(pXOrArray->isArray())
{
- // the user has passed a complete tqgeometry array as first parameter
+ // the user has passed a complete geometry array as first parameter
// make sure it has at least 4 elements
if(pXOrArray->array()->size() < 4)
{
@@ -1009,12 +1009,12 @@ bool KviKvsObject_widget::function_setGeometry(KviKvsObjectFunctionCall *c)
// no parameter was set in that place
if(!(pX && pY && pW && pH))
{
- c->error(__tr2qs("One of the tqgeometry array parameters is empty"));
+ c->error(__tr2qs("One of the geometry array parameters is empty"));
return false;
}
if(!(pX->asInteger(iX) && pY->asInteger(iY) && pW->asInteger(iW) && pH->asInteger(iH)))
{
- c->error(__tr2qs("One of the tqgeometry array parameters didn't evaluate to an integer"));
+ c->error(__tr2qs("One of the geometry array parameters didn't evaluate to an integer"));
return false;
}
// ok: the params are correct
@@ -522,7 +522,7 @@ const int widgettypes_cod[] = {
// may happen that widget() will be zero here too:
// If the TQt "physical" widget gets destroyed
- // by some external factor (for example when tqchildren
+ // by some external factor (for example when children
// of a wrapper widget destroyed by KVIrc).
//